@@ -1859,8 +1859,8 @@ void SoundManager::applyEnvelope(bool forceRedraw)
         float* outputBufferLeft=SoundHolder::getLeftChannel(AFTER_ENVELOPE);
         float* outputBufferRight=SoundHolder::getRightChannel(AFTER_ENVELOPE);
         if(!envelopeData || !envelopeArray || lockedBeatLines.count()==0 || !envelopeData->isEnabled()){
-                std::memcpy(outputBufferLeft,inputBufferLeft,sizeof(long)*getFrames());
-                std::memcpy(outputBufferRight,inputBufferRight,sizeof(long)*getFrames());
+                memcpy(outputBufferLeft,inputBufferLeft,sizeof(float)*getFrames());
+                memcpy(outputBufferRight,inputBufferRight,sizeof(float)*getFrames());
         }else{
             cout<<"Applying Envelope: "<<envelopeData->toString()<<"\n";
             cout<<"lockedBeatLines.count(): "<<lockedBeatLines.count()<<"\n";
